@@ -768,6 +768,7 @@ def Store(conf, backend=None):
         return MultiTenantStore(conf, backend=backend)
     return SingleTenantStore(conf, backend=backend)
 
+
 Store.OPTIONS = _SWIFT_OPTS + sutils.swift_opts + buffered.BUFFERING_OPTS
 
 
@@ -806,6 +807,10 @@ class BaseStore(driver.Store):
         self.insecure = glance_conf.swift_store_auth_insecure
         self.ssl_compression = glance_conf.swift_store_ssl_compression
         self.cacert = glance_conf.swift_store_cacert
+        if self.insecure:
+            self.ks_verify = False
+        else:
+            self.ks_verify = self.cacert or True
         if swiftclient is None:
             msg = _("Missing dependency python_swiftclient.")
             raise exceptions.BadStoreConfiguration(store_name="swift",
@@ -1060,7 +1065,7 @@ class BaseStore(driver.Store):
 
                 metadata = {}
                 if self.backend_group:
-                    metadata['backend'] = u"%s" % self.backend_group
+                    metadata['store'] = u"%s" % self.backend_group
 
                 return (location.get_uri(credentials_included=include_creds),
                         image_size, obj_etag, os_hash_value.hexdigest(),
@@ -1118,7 +1123,7 @@ class BaseStore(driver.Store):
                     try:
                         connection.delete_object(obj_container,
                                                  segment['name'])
-                    except swiftclient.ClientException as e:
+                    except swiftclient.ClientException:
                         msg = _('Unable to delete segment %(segment_name)s')
                         msg = msg % {'segment_name': segment['name']}
                         LOG.exception(msg)
@@ -1454,7 +1459,7 @@ class SingleTenantStore(BaseStore):
             project_domain_id=self.project_domain_id,
             project_domain_name=self.project_domain_name)
 
-        sess = ks_session.Session(auth=password, verify=not self.insecure)
+        sess = ks_session.Session(auth=password, verify=self.ks_verify)
         return ks_client.Client(session=sess)
 
     def get_manager(self, store_location, context=None, allow_reauth=False):
@@ -1594,9 +1599,9 @@ class MultiTenantStore(BaseStore):
         # create client for multitenant user(trustor)
         trustor_auth = ks_identity.V3Token(auth_url=auth_address,
                                            token=context.auth_token,
-                                           project_id=context.tenant)
+                                           project_id=context.project_id)
         trustor_sess = ks_session.Session(auth=trustor_auth,
-                                          verify=not self.insecure)
+                                          verify=self.ks_verify)
         trustor_client = ks_client.Client(session=trustor_sess)
         auth_ref = trustor_client.session.auth.get_auth_ref(trustor_sess)
         roles = [t['name'] for t in auth_ref['roles']]
@@ -1613,7 +1618,7 @@ class MultiTenantStore(BaseStore):
             project_domain_id=project_domain_id,
             project_domain_name=project_domain_name)
         trustee_sess = ks_session.Session(auth=password,
-                                          verify=not self.insecure)
+                                          verify=self.ks_verify)
         trustee_client = ks_client.Client(session=trustee_sess)
 
         # request glance user id - we will use it as trustee user
@@ -1621,8 +1626,8 @@ class MultiTenantStore(BaseStore):
 
         # create trust for trustee user
         trust_id = trustor_client.trusts.create(
-            trustee_user=trustee_user_id, trustor_user=context.user,
-            project=context.tenant, impersonation=True,
+            trustee_user=trustee_user_id, trustor_user=context.user_id,
+            project=context.project_id, impersonation=True,
             role_names=roles
         ).id
         # initialize a new client with trust and trustee credentials
@@ -1640,7 +1645,7 @@ class MultiTenantStore(BaseStore):
         # now we can authenticate against KS
         # as trustee of user who provided token
         client_sess = ks_session.Session(auth=client_password,
-                                         verify=not self.insecure)
+                                         verify=self.ks_verify)
         return ks_client.Client(session=client_sess)
 
     def get_manager(self, store_location, context=None, allow_reauth=False):
