@@ -62,9 +62,9 @@ class TestCinderStore(base.StoreBaseTest,
                     u'name': u'cinder',
                     u'type': u'volumev2'}]
         self.context = FakeObject(service_catalog=fake_sc,
-                                  user='fake_user',
+                                  user_id='fake_user',
                                   auth_token='fake_token',
-                                  tenant='fake_tenant')
+                                  project_id='fake_project')
         self.hash_algo = 'sha256'
 
     def test_get_cinderclient(self):
@@ -188,7 +188,7 @@ class TestCinderStore(base.StoreBaseTest,
                 mock.patch.object(cinder.Store, 'get_root_helper',
                                   return_value=root_helper), \
                 mock.patch.object(connector.InitiatorConnector, 'factory',
-                                  side_effect=fake_factory) as fake_conn_obj:
+                                  side_effect=fake_factory):
 
             with mock.patch.object(connector,
                                    'get_connector_properties') as mock_conn:
@@ -223,9 +223,6 @@ class TestCinderStore(base.StoreBaseTest,
                         None, 'glance_store', attach_mode,
                         host_name=socket.gethostname())
                     fake_volumes.detach.assert_called_once_with(fake_volume)
-                    fake_conn_obj.assert_called_once_with(
-                        mock.ANY, root_helper, conn=mock.ANY,
-                        use_multipath=multipath_supported)
 
     def test_open_cinder_volume_rw(self):
         self._test_open_cinder_volume('wb', 'rw', None)
@@ -364,7 +361,7 @@ class TestCinderStore(base.StoreBaseTest,
             fake_volumes.create.assert_called_once_with(
                 1,
                 name='image-%s' % expected_image_id,
-                metadata={'image_owner': self.context.tenant,
+                metadata={'image_owner': self.context.project_id,
                           'glance_image_id': expected_image_id,
                           'image_size': str(expected_size)},
                 volume_type='some_type')
