@@ -89,15 +89,15 @@ class TestMultiCinderStore(base.MultiStoreBaseTest,
                     u'name': u'cinder',
                     u'type': u'volumev2'}]
         self.context = FakeObject(service_catalog=fake_sc,
-                                  user='fake_user',
+                                  user_id='fake_user',
                                   auth_token='fake_token',
-                                  tenant='fake_tenant')
+                                  project_id='fake_project')
         self.fake_admin_context = mock.MagicMock()
         self.fake_admin_context.elevated.return_value = FakeObject(
             service_catalog=fake_sc,
-            user='admin_user',
+            user_id='admin_user',
             auth_token='admin_token',
-            tenant='admin_project')
+            project_id='admin_project')
 
     def test_location_url_prefix_is_set(self):
         self.assertEqual("cinder://cinder1", self.store.url_prefix)
@@ -219,7 +219,7 @@ class TestMultiCinderStore(base.MultiStoreBaseTest,
                 mock.patch.object(cinder.Store, 'get_root_helper',
                                   return_value=root_helper), \
                 mock.patch.object(connector.InitiatorConnector, 'factory',
-                                  side_effect=fake_factory) as fake_conn_obj:
+                                  side_effect=fake_factory):
 
             with mock.patch.object(connector,
                                    'get_connector_properties') as mock_conn:
@@ -238,9 +238,6 @@ class TestMultiCinderStore(base.MultiStoreBaseTest,
                     None, 'glance_store', attach_mode,
                     host_name=socket.gethostname())
                 fake_volumes.detach.assert_called_once_with(fake_volume)
-                fake_conn_obj.assert_called_once_with(
-                    mock.ANY, root_helper, conn=mock.ANY,
-                    use_multipath=multipath_supported)
 
     def test_open_cinder_volume_rw(self):
         self._test_open_cinder_volume('wb', 'rw', None)
@@ -434,7 +431,7 @@ class TestMultiCinderStore(base.MultiStoreBaseTest,
             fake_volumes.create.assert_called_once_with(
                 1,
                 name='image-%s' % expected_image_id,
-                metadata={'image_owner': self.context.tenant,
+                metadata={'image_owner': self.context.project_id,
                           'glance_image_id': expected_image_id,
                           'image_size': str(expected_size)},
                 volume_type='some_type')
