@@ -16,9 +16,10 @@
 """Tests the Swift backend store"""
 
 import copy
+from unittest import mock
+
 import fixtures
 import hashlib
-import mock
 import tempfile
 import uuid
 
@@ -46,8 +47,8 @@ from glance_store.tests.unit import test_store_capabilities
 
 CONF = cfg.CONF
 
-FAKE_UUID = lambda: str(uuid.uuid4())
-FAKE_UUID2 = lambda: str(uuid.uuid4())
+FAKE_UUID = lambda: str(uuid.uuid4())  # noqa: E731
+FAKE_UUID2 = lambda: str(uuid.uuid4())  # noqa: E731
 
 Store = swift.Store
 FIVE_KB = 5 * units.Ki
@@ -407,7 +408,7 @@ class SwiftTests(object):
         loc, size, checksum, metadata = self.store.add(
             expected_image_id, image_swift, expected_swift_size)
 
-        self.assertEqual("swift1", metadata["backend"])
+        self.assertEqual("swift1", metadata["store"])
         self.assertEqual(expected_location, loc)
         self.assertEqual(expected_swift_size, size)
         self.assertEqual(expected_checksum, checksum)
@@ -446,7 +447,7 @@ class SwiftTests(object):
         location, size, checksum, arg = self.store.add(expected_image_id,
                                                        image_swift,
                                                        expected_swift_size)
-        self.assertEqual("swift1", arg['backend'])
+        self.assertEqual("swift1", arg['store'])
         self.assertEqual(expected_location, location)
 
     @mock.patch('glance_store._drivers.swift.utils'
@@ -492,7 +493,7 @@ class SwiftTests(object):
                                                   expected_swift_size,
                                                   context=ctxt)
 
-        self.assertEqual("swift1", metadata['backend'])
+        self.assertEqual("swift1", metadata['store'])
         # ensure that image add uses user's context
         self.assertEqual(expected_location, loc)
 
@@ -535,7 +536,7 @@ class SwiftTests(object):
                                                            image_swift,
                                                            expected_swift_size)
 
-            self.assertEqual("swift1", metadata['backend'])
+            self.assertEqual("swift1", metadata['store'])
             self.assertEqual(expected_location, loc)
             self.assertEqual(expected_swift_size, size)
             self.assertEqual(expected_checksum, checksum)
@@ -615,7 +616,7 @@ class SwiftTests(object):
                                                        image_swift,
                                                        expected_swift_size)
 
-        self.assertEqual("swift1", metadata['backend'])
+        self.assertEqual("swift1", metadata['store'])
         self.assertEqual(expected_location, loc)
         self.assertEqual(expected_swift_size, size)
         self.assertEqual(expected_checksum, checksum)
@@ -664,7 +665,7 @@ class SwiftTests(object):
                                                        image_swift,
                                                        expected_swift_size)
 
-        self.assertEqual("swift1", metadata['backend'])
+        self.assertEqual("swift1", metadata['store'])
         self.assertEqual(expected_location, loc)
         self.assertEqual(expected_swift_size, size)
         self.assertEqual(expected_checksum, checksum)
@@ -849,7 +850,7 @@ class SwiftTests(object):
                                                        expected_swift_size,
                                                        context=ctxt)
 
-        self.assertEqual("swift1", metadata['backend'])
+        self.assertEqual("swift1", metadata['store'])
         self.assertEqual(expected_location, location)
 
     @mock.patch('glance_store._drivers.swift.utils'
@@ -887,7 +888,7 @@ class SwiftTests(object):
             self.store.large_object_chunk_size = orig_temp_size
             self.store.large_object_size = orig_max_size
 
-        self.assertEqual("swift1", metadata['backend'])
+        self.assertEqual("swift1", metadata['store'])
         self.assertEqual(expected_location, loc)
         self.assertEqual(expected_swift_size, size)
         self.assertEqual(expected_checksum, checksum)
@@ -948,7 +949,7 @@ class SwiftTests(object):
             self.store.large_object_size = orig_max_size
             MAX_SWIFT_OBJECT_SIZE = orig_max_swift_object_size
 
-        self.assertEqual("swift1", metadata['backend'])
+        self.assertEqual("swift1", metadata['store'])
         self.assertEqual(expected_location, loc)
         self.assertEqual(expected_swift_size, size)
         self.assertEqual(expected_checksum, checksum)
@@ -1255,6 +1256,13 @@ class SwiftTests(object):
             self._init_client(verify=True, swift_store_multi_tenant=True,
                               swift_store_config_file=None)
 
+    def test_init_client_multi_tenant_swift_cacert(self):
+        """Test that keystone client was initialized with swift cacert"""
+        with mock.patch.object(swift.MultiTenantStore, '_set_url_prefix'):
+            self._init_client(verify='/foo/bar', swift_store_multi_tenant=True,
+                              swift_store_config_file=None,
+                              swift_store_cacert='/foo/bar')
+
     def test_init_client_multi_tenant_insecure(self):
         """
         Test that keystone client was initialized correctly with no
@@ -1301,7 +1309,7 @@ class SwiftTests(object):
         mock_identity.V3Token.assert_called_once_with(
             auth_url=default_swift_reference.get('auth_address'),
             token=ctxt.auth_token,
-            project_id=ctxt.tenant
+            project_id=ctxt.project_id
         )
         mock_session.Session.assert_any_call(auth=mock_identity.V3Token(),
                                              verify=verify)
@@ -1323,8 +1331,8 @@ class SwiftTests(object):
                                              verify=verify)
         mock_client.Client.assert_any_call(session=trustee_session)
         trustor_client.trusts.create.assert_called_once_with(
-            trustee_user='fake_user', trustor_user=ctxt.user,
-            project=ctxt.tenant, impersonation=True,
+            trustee_user='fake_user', trustor_user=ctxt.user_id,
+            project=ctxt.project_id, impersonation=True,
             role_names=['fake_role']
         )
         mock_identity.V3Password.assert_any_call(
